"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stubsToReact = exports.verifyStubsToReact = void 0;
const utils_1 = require("../../utils");
const constants_1 = require("../../constants");
const supportedProps = [
    'useRef',
    'useStore',
    'useState',
    'onMount',
    'onUnMount',
    'onUpdate',
    'useDefaultProps',
    'Show',
    'For'
];
const unsupportedProps = [
    'useEffect'
];
const stateProps = ['useStore', 'useState'];
const lifecycleProps = ['onUpdate', 'onMount', 'onUnMount'];
const removeProps = [
    'Show',
    'For',
    'useMetadata',
    'useDefaultProps'
];
const verifyStubsToReact = (path) => {
    if (path.node.source.value === constants_1.STUB_SOURCE) {
        path.node.specifiers.forEach(specifier => {
            if (specifier.type === 'ImportSpecifier' && specifier.imported.type === 'Identifier') {
                if (supportedProps.includes(specifier.imported.name)) {
                    if (specifier.imported.name !== specifier.local.name) {
                        (0, utils_1.throwError)('supported stub props must be imported directly');
                    }
                }
            }
        });
        // props 
        unsupportedProps.forEach(name => {
            if (path.node.specifiers.find(a => a.type === 'ImportSpecifier' &&
                a.imported.type === 'Identifier' &&
                a.imported.name === name)) {
                (0, utils_1.throwError)('there is no useEffect, use onMount, onUnMount, or onUpdate methods');
            }
        });
    }
    ;
};
exports.verifyStubsToReact = verifyStubsToReact;
const stubsToReact = (path) => {
    (0, exports.verifyStubsToReact)(path);
    /// useRef, useStore, useState, useEffect, userDefaultProps
    if (path.node.source.value === constants_1.STUB_SOURCE) {
        supportedProps.forEach(name => {
            if (path.node.specifiers.find(a => a.type === 'ImportSpecifier' &&
                a.imported.type === 'Identifier' &&
                a.imported.name === name)) {
                path.node.source.value = "react";
            }
        });
        // Rename specifiers
        path.node.specifiers.forEach(specifier => {
            if (specifier.type === 'ImportSpecifier' && specifier.imported.type === 'Identifier') {
                if (stateProps.includes(specifier.imported.name)) {
                    specifier.imported.name = 'useState';
                    specifier.local.name = 'useState';
                }
                else if (lifecycleProps.includes(specifier.imported.name)) {
                    specifier.imported.name = 'useEffect';
                    specifier.local.name = 'useEffect';
                }
            }
        });
        // Remove duplicates
        const uniqueNames = new Set();
        path.node.specifiers = path.node.specifiers.filter(specifier => {
            if (specifier.type === 'ImportSpecifier' && specifier.imported.type === 'Identifier') {
                if (!uniqueNames.has(specifier.imported.name)) {
                    uniqueNames.add(specifier.imported.name);
                    return true; // Keep this specifier
                }
                return false; // Remove duplicate
            }
            return true; // Keep non-import-specifier nodes
        });
        // Remove meta props
        const newSpecifiers = path.node.specifiers.filter(specifier => !(specifier.type === 'ImportSpecifier' &&
            specifier.imported.type === 'Identifier' &&
            removeProps.includes(specifier.imported.name)));
        if (newSpecifiers.length === 0) {
            // If all specifiers are removed, remove the whole import declaration
            path.remove();
        }
        else {
            // Otherwise, replace the original specifiers with the new array
            path.node.specifiers = newSpecifiers;
        }
    }
};
exports.stubsToReact = stubsToReact;
